pub struct LocalCheckRequest { /* private fields */ }Expand description
Capability-scoped request naming only an installed allowlist entry.
Implementations
Sourceimpl LocalCheckRequest
impl LocalCheckRequest
Sourcepub fn new(
packet: PacketRef,
command: CommandId,
source: BuildSourceRef,
grant: CapabilityGrantRef,
) -> Self
pub fn new( packet: PacketRef, command: CommandId, source: BuildSourceRef, grant: CapabilityGrantRef, ) -> Self
Creates a request that cannot alter the installed command bytes or policy.
Sourcepub fn with_network_grant(
self,
capability: CapabilityName,
grant: CapabilityGrantRef,
) -> Self
pub fn with_network_grant( self, capability: CapabilityName, grant: CapabilityGrantRef, ) -> Self
Adds authority for the exact separately scoped network capability.
Sourcepub const fn source(&self) -> &BuildSourceRef
pub const fn source(&self) -> &BuildSourceRef
Returns the sealed build-source identity.
Sourcepub const fn grant(&self) -> &CapabilityGrantRef
pub const fn grant(&self) -> &CapabilityGrantRef
Returns the least-authority grant identity.
Sourcepub const fn network_grant(
&self,
) -> Option<&(CapabilityName, CapabilityGrantRef)>
pub const fn network_grant( &self, ) -> Option<&(CapabilityName, CapabilityGrantRef)>
Returns the separately scoped network capability and grant, when supplied.
Sourcepub fn canonical_datum(&self) -> Datum
pub fn canonical_datum(&self) -> Datum
Returns the request’s canonical semantic value.